@@ -1,6 +1,6 @@
 # !/usr/bin/env python
 # encoding: utf-8
 
-from .actions import action
+from .actions import action, basic_action
 from .auth import auth
-from .validators import validator
\ No newline at end of file
+from .validators import validator
